/****************************************************************************
** Meta object code from reading C++ file 'webseed.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libktorrent-26.04.2/src/download/webseed.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'webseed.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2bt7WebSeedE_t {};
} // unnamed namespace

template <> constexpr inline auto bt::WebSeed::qt_create_metaobjectdata<qt_meta_tag_ZN2bt7WebSeedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "bt::WebSeed",
        "chunkReady",
        "",
        "bt::Chunk*",
        "c",
        "finished",
        "chunkDownloadStarted",
        "bt::WebSeedChunkDownload*",
        "cd",
        "Uint32",
        "chunk",
        "chunkDownloadFinished",
        "reset",
        "redirected",
        "QUrl",
        "to_url"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'chunkReady'
        QtMocHelpers::SignalData<void(bt::Chunk *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'finished'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'chunkDownloadStarted'
        QtMocHelpers::SignalData<void(bt::WebSeedChunkDownload *, Uint32)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Signal 'chunkDownloadFinished'
        QtMocHelpers::SignalData<void(bt::WebSeedChunkDownload *, Uint32)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'reset'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'redirected'
        QtMocHelpers::SlotData<void(const QUrl &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WebSeed, qt_meta_tag_ZN2bt7WebSeedE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject bt::WebSeed::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2bt7WebSeedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2bt7WebSeedE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2bt7WebSeedE_t>.metaTypes,
    nullptr
} };

void bt::WebSeed::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WebSeed *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->chunkReady((*reinterpret_cast<std::add_pointer_t<bt::Chunk*>>(_a[1]))); break;
        case 1: _t->finished(); break;
        case 2: _t->chunkDownloadStarted((*reinterpret_cast<std::add_pointer_t<bt::WebSeedChunkDownload*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Uint32>>(_a[2]))); break;
        case 3: _t->chunkDownloadFinished((*reinterpret_cast<std::add_pointer_t<bt::WebSeedChunkDownload*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Uint32>>(_a[2]))); break;
        case 4: _t->reset(); break;
        case 5: _t->redirected((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WebSeed::*)(bt::Chunk * )>(_a, &WebSeed::chunkReady, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebSeed::*)()>(_a, &WebSeed::finished, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebSeed::*)(bt::WebSeedChunkDownload * , Uint32 )>(_a, &WebSeed::chunkDownloadStarted, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebSeed::*)(bt::WebSeedChunkDownload * , Uint32 )>(_a, &WebSeed::chunkDownloadFinished, 3))
            return;
    }
}

const QMetaObject *bt::WebSeed::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *bt::WebSeed::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2bt7WebSeedE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "WebSeedInterface"))
        return static_cast< WebSeedInterface*>(this);
    return QObject::qt_metacast(_clname);
}

int bt::WebSeed::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void bt::WebSeed::chunkReady(bt::Chunk * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void bt::WebSeed::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void bt::WebSeed::chunkDownloadStarted(bt::WebSeedChunkDownload * _t1, Uint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void bt::WebSeed::chunkDownloadFinished(bt::WebSeedChunkDownload * _t1, Uint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
QT_WARNING_POP
